"""
Author: Michel Peltriaux
Organization: Struktur- und Genehmigungsdirektion Nord, Rhineland-Palatinate, Germany
Contact: michel.peltriaux@sgdnord.rlp.de
Created on: 24.08.21

"""
from django.urls import path

from compensation.autocomplete.eco_account import EcoAccountAutocomplete
from compensation.views.eco_account.eco_account import index_view, new_view, new_id_view, edit_view, remove_view, \
    detail_view
from compensation.views.eco_account.log import EcoAccountLogView
from compensation.views.eco_account.record import EcoAccountRecordView
from compensation.views.eco_account.report import report_view
from compensation.views.eco_account.resubmission import EcoAccountResubmissionView
from compensation.views.eco_account.state import state_new_view, state_remove_view, state_edit_view
from compensation.views.eco_account.action import action_edit_view, action_new_view, action_remove_view
from compensation.views.eco_account.deadline import deadline_new_view, deadline_edit_view, deadline_remove_view
from compensation.views.eco_account.share import share_view, create_share_view
from compensation.views.eco_account.document import get_document_view, new_document_view, remove_document_view, \
    edit_document_view
from compensation.views.eco_account.deduction import deduction_edit_view, deduction_remove_view, new_deduction_view

app_name = "acc"
urlpatterns = [
    path("", index_view, name="index"),
    path('new/', new_view, name='new'),
    path('new/id', new_id_view, name='new-id'),
    path('<id>', detail_view, name='detail'),
    path('<id>/log', EcoAccountLogView.as_view(), name='log'),
    path('<id>/record', EcoAccountRecordView.as_view(), name='record'),
    path('<id>/report', report_view, name='report'),
    path('<id>/edit', edit_view, name='edit'),
    path('<id>/remove', remove_view, name='remove'),
    path('<id>/resub', EcoAccountResubmissionView.as_view(), name='resubmission-create'),

    path('<id>/state/new', state_new_view, name='new-state'),
    path('<id>/state/<state_id>/edit', state_edit_view, name='state-edit'),
    path('<id>/state/<state_id>/remove', state_remove_view, name='state-remove'),

    path('<id>/action/new', action_new_view, name='new-action'),
    path('<id>/action/<action_id>/edit', action_edit_view, name='action-edit'),
    path('<id>/action/<action_id>/remove', action_remove_view, name='action-remove'),

    path('<id>/deadline/new', deadline_new_view, name="new-deadline"),
    path('<id>/deadline/<deadline_id>/edit', deadline_edit_view, name='deadline-edit'),
    path('<id>/deadline/<deadline_id>/remove', deadline_remove_view, name='deadline-remove'),

    path('<id>/share/<token>', share_view, name='share'),
    path('<id>/share', create_share_view, name='share-create'),

    # Documents
    path('<id>/document/new/', new_document_view, name='new-doc'),
    path('<id>/document/<doc_id>', get_document_view, name='get-doc'),
    path('<id>/document/<doc_id>/edit', edit_document_view, name='edit-doc'),
    path('<id>/document/<doc_id>/remove/', remove_document_view, name='remove-doc'),

    # Eco-account deductions
    path('<id>/deduction/<deduction_id>/remove', deduction_remove_view, name='remove-deduction'),
    path('<id>/deduction/<deduction_id>/edit', deduction_edit_view, name='edit-deduction'),
    path('<id>/deduct/new', new_deduction_view, name='new-deduction'),

    # Autocomplete
    path("atcmplt/eco-accounts", EcoAccountAutocomplete.as_view(), name="autocomplete"),
]
